@@ -9,7 +9,7 @@ miquire :mui, 'textselector'
 miquire :mui, 'sub_parts_helper'
 miquire :mui, 'replyviewer'
 miquire :mui, 'sub_parts_favorite'
-miquire :mui, 'sub_parts_retweet'
+miquire :mui, 'sub_parts_share'
 miquire :mui, 'sub_parts_quote'
 miquire :mui, 'markup_generator'
 miquire :mui, 'special_edge'
@@ -36,6 +36,8 @@ class Gdk::MiraclePainter < Gtk::Object
   Event = Struct.new(:event, :message, :timeline, :miraclepainter)
   WHITE = ([0xffff]*3).freeze
   BLACK = [0, 0, 0].freeze
+  NUMERONYM_MATCHER = /[a-zA-Z]{4,}/.freeze
+  NUMERONYM_CONVERTER = ->(r) { "#{r[0]}#{r.size-2}#{r[-1]}" }
 
   attr_reader :message, :p_message, :tree, :selected
 
@@ -130,7 +132,7 @@ class Gdk::MiraclePainter < Gtk::Object
       @pixbuf
     else
       @last_modify_height = height
-      Skin['loading.png'].pixbuf(width: @last_modify_height, height: @last_modify_height)
+      Skin[:loading].pixbuf(width: @last_modify_height, height: @last_modify_height)
     end
   end
 
@@ -339,15 +341,17 @@ class Gdk::MiraclePainter < Gtk::Object
   private
 
   def dummy_context
-    Gdk::Pixmap.new(nil, 1, 1, color).create_cairo_context end
+    Cairo::Context.dummy
+  end
+  deprecate :dummy_context, "Cairo::Context.dummy", 2020, 6
 
   # 本文のための Pango::Layout のインスタンスを返す
-  def main_message(context = dummy_context)
+  def main_message(context = Cairo::Context.dummy)
     layout = context.create_pango_layout
     font = Plugin.filtering(:message_font, message, nil).last
     layout.font_description = font_description(font) if font
     layout.width = pos.main_text.width * Pango::SCALE
-    layout.attributes = textselector_attr_list(description_attr_list(emoji_height: emoji_height(layout.font_description)))
+    layout.attributes = textselector_attr_list(description_attr_list(emoji_height: layout.font_description.forecast_font_size))
     layout.wrap = Pango::WrapMode::CHAR
     color = Plugin.filtering(:message_font_color, message, nil).last
     color = BLACK if not(color and color.is_a? Array and 3 == color.size)
@@ -368,8 +372,10 @@ class Gdk::MiraclePainter < Gtk::Object
     end
     layout end
 
-  memoize def font_description(font)
-    Pango::FontDescription.new(font)
+  @@font_description = Hash.new{|h,k| h[k] = {} } # {scale => {font => FontDescription}}
+  def font_description(font)
+    @@font_description[scale(0xffff)][font] ||=
+      Pango::FontDescription.new(font).tap{|fd| fd.size = scale(fd.size) }
   end
 
   # 絵文字を描画する時の一辺の大きさを返す
@@ -377,15 +383,14 @@ class Gdk::MiraclePainter < Gtk::Object
   # [font] font description
   # ==== Return
   # [Integer] 高さ(px)
-  memoize def emoji_height(font)
-    layout = dummy_context.create_pango_layout
-    layout.font_description = font
-    layout.text = '.'
-    layout.pixel_size[1]
+  def emoji_height(font)
+    font.forecast_font_size
   end
+  deprecate :emoji_height, "Pango::FontDescription#forecast_font_size", 2020, 6
+
 
   # ヘッダ（左）のための Pango::Layout のインスタンスを返す
-  def header_left(context = dummy_context)
+  def header_left(context = Cairo::Context.dummy)
     attr_list, text = header_left_markup
     color = Plugin.filtering(:message_header_left_font_color, message, nil).last
     color = BLACK if not(color and color.is_a? Array and 3 == color.size)
@@ -400,14 +405,24 @@ class Gdk::MiraclePainter < Gtk::Object
   def header_left_markup
     user = message.user
     if user.respond_to?(:idname)
-      Pango.parse_markup("<b>#{Pango.escape(user.idname)}</b> #{Pango.escape(user.name || '')}")
+      Pango.parse_markup("<b>#{Pango.escape(rinsuki_abbr(user))}</b> #{Pango.escape(user.name || '')}")
     else
       Pango.parse_markup(Pango.escape(user.name || ''))
     end
   end
 
+  def rinsuki_abbr(user)
+    return user.idname unless UserConfig[:idname_abbr]
+    prefix, domain = user.idname.split('@', 2)
+    if domain
+      "#{prefix}@#{domain.gsub(NUMERONYM_MATCHER, &NUMERONYM_CONVERTER)}"
+    else
+      user.idname
+    end
+  end
+
   # ヘッダ（右）のための Pango::Layout のインスタンスを返す
-  def header_right(context = dummy_context)
+  def header_right(context = Cairo::Context.dummy)
     hms = timestamp_label
     attr_list, text = Pango.parse_markup(hms)
     layout = context.create_pango_layout
@@ -437,7 +452,8 @@ class Gdk::MiraclePainter < Gtk::Object
   # pixbufを組み立てる
   def gen_pixbuf
     @pixmap = gen_pixmap
-    GdkPixbuf::Pixbuf.from_drawable(nil, @pixmap, 0, 0, width, height)
+    src_width, src_height = @pixmap.size
+    GdkPixbuf::Pixbuf.from_drawable(nil, @pixmap, 0, 0, src_width, src_height)
   end
 
   # アイコンのpixbufを返す
