@@ -6,6 +6,7 @@ require 'gtk2'
 require 'cairo'
 
 module Gdk::SubPartsHelper
+  extend Gem::Deprecate
 
   def initialize(*args)
     @subparts_height = nil
@@ -41,6 +42,7 @@ module Gdk::SubPartsHelper
     subparts.inject(0){ |sum, part| sum + part.height } end end
 
 class Gdk::SubParts
+  extend Gem::Deprecate
   include UiThreadOnly
 
   attr_reader :helper
@@ -71,6 +73,8 @@ class Gdk::SubParts
     0 end
 
   def dummy_context
-    Gdk::Pixmap.new(nil, 1, 1, @helper.color).create_cairo_context end
+    Cairo::Context.dummy
+  end
+  deprecate :dummy_context, "Cairo::Context.dummy", 2020, 6
 
 end
