@@ -50,7 +50,7 @@ class Gtk::MessagePicker < Gtk::EventBox
 
   def add_condition(expr = DEFAULT_CONDITION)
     pack = Gtk::HBox.new
-    close = Gtk::Button.new.add(Gtk::WebIcon.new(Skin['close.png'], 16, 16)).set_relief(Gtk::RELIEF_NONE)
+    close = Gtk::Button.new.add(Gtk::WebIcon.new(Skin[:close], 16, 16)).set_relief(Gtk::RELIEF_NONE)
     close.signal_connect(:clicked){
       @container.remove(pack)
       pack.destroy
@@ -125,7 +125,7 @@ class Gtk::MessagePicker < Gtk::EventBox
                                      unless new === nil
                                        @subject = new.to_sym
                                        call end
-                                     sensitivity = extract_condition[@subject][:operator] && 0 != extract_condition[@subject][:args]
+                                     sensitivity = extract_condition.dig(@subject, :operator) && 0 != extract_condition.dig(@subject, :args)
                                      w_argument.set_sensitive(sensitivity)
                                      w_operator.set_sensitive(sensitivity)
                                      @subject.to_s },
