@@ -33,12 +33,12 @@ module Gtk
         photo = Enumerator.new{|y|
           Plugin.filtering(:photo_filter, url, y)
         }.first
-        super(load_model(photo || Skin['notfound.png'], rect))
+        super(load_model(photo || Skin[:notfound], rect))
       end
     end
 
     def load_model(photo, rect)
-      photo.load_pixbuf(width: rect.width, height: rect.height){|pb|
+      photo.load_pixbuf(width: Gdk.scale(rect.width), height: Gdk.scale(rect.height)){|pb|
         update_pixbuf(pb)
       }
     end
@@ -50,6 +50,5 @@ module Gtk
         self.notify_observers
       end
     end
-
   end
 end
