@@ -10,25 +10,25 @@ Plugin.create :command do
 
   command(:copy_selected_region,
           name: _('コピー'),
-          condition: Plugin::Command[:HasOneMessage, :TimelineTextSelected],
+          condition: ->opt{ opt.messages.size == 1 && opt.widget&.selected_text(opt.messages.first)},
           visible: true,
-          icon: Skin['copy.png'],
+          icon: Skin[:copy],
           role: :timeline) do |opt|
     ::Gtk::Clipboard.copy(opt.widget.selected_text(opt.messages.first)) end
 
   command(:copy_description,
           name: _('本文をコピー'),
-          condition: Plugin::Command[:HasOneMessage],
+          condition: ->opt{ opt.messages.size == 1 },
           visible: true,
-          icon: Skin['copy_all.png'],
+          icon: Skin[:copy_all],
           role: :timeline) do |opt|
     ::Gtk::Clipboard.copy(opt.messages.first.description) end
 
   command(:reply,
           name: _('返信'),
-          condition: Plugin::Command[:CanReplyAll],
+          condition: ->opt{ !opt.messages.empty? && compose?(opt.world, to: opt.messages) },
           visible: true,
-          icon: Skin['reply.png'],
+          icon: Skin[:reply],
           role: :timeline) do |opt|
     messages = opt.messages
     opt.widget.create_postbox(to: messages,
@@ -37,9 +37,9 @@ Plugin.create :command do
 
   command(:reply_all,
           name: _('全員に返信'),
-          condition: Plugin::Command[:CanReplyAll],
+          condition: ->opt{ !opt.messages.empty? && compose?(opt.world, to: opt.messages) },
           visible: true,
-          icon: Skin['reply.png'],
+          icon: Skin[:reply],
           role: :timeline) do |opt|
     messages = opt.messages.map{ |m| m.ancestors.to_a }.flatten
     opt.widget.create_postbox(to: messages,
@@ -48,7 +48,7 @@ Plugin.create :command do
 
   command(:legacy_retweet,
           name: _('引用'),
-          condition: Plugin::Command[:HasOneMessage, :CanReplyAll],
+          condition: ->opt{ opt.messages.size == 1 && compose?(opt.world, to: opt.messages) },
           visible: true,
           role: :timeline) do |opt|
     m = opt.messages.first
@@ -59,66 +59,62 @@ Plugin.create :command do
 
   command(:retweet,
           name: _('リツイート'),
-          condition: Plugin::Command[:CanReTweetAny],
+          condition: ->opt{ opt.messages.any?{|m| share?(opt.world, m) && !shared?(opt.world, m) } },
           visible: true,
-          icon: Skin['retweet.png'],
+          icon: Skin[:retweet],
           role: :timeline) do |opt|
-    world, = Plugin.filtering(:world_current, nil)
-    target = opt.messages.select{|m| share?(m, world) }.reject{|m| shared?(m, world) }.map(&:introducer)
-    if target.any?{|message| message.from_me?([world]) }
+    target = opt.messages.select{|m| share?(m, opt.world) }.reject{|m| shared?(m, opt.world) }.map(&:introducer)
+    if target.any?{|message| message.from_me?([opt.world]) }
       if ::Gtk::Dialog.confirm(_('過去の栄光にすがりますか？'))
-        target.each{|m| share(m, world) }
+        target.each{|m| share(m, opt.world) }
       end
     else
-      target.each{|m| share(m, world) }
+      target.each{|m| share(m, opt.world) }
     end
   end
 
   command(:delete_retweet,
           name: _('リツイートをキャンセル'),
-          condition: Plugin::Command[:IsReTweetedAll],
+          condition: ->opt{ !opt.messages.empty? && opt.messages.all?{|m| destroy_share?(opt.world, m) } },
           visible: true,
-          icon: Skin['retweet_cancel.png'],
+          icon: Skin[:retweet_cancel],
           role: :timeline) do |opt|
-    current_world, = Plugin.filtering(:world_current, nil)
     Delayer::Deferred.when(
-      opt.messages.map{|m| destroy_share(current_world, m) }
+      opt.messages.map{|m| destroy_share(opt.world, m) }
     ).terminate(_('リツイートをキャンセルしている途中でエラーが発生しました'))
   end
 
   command(:favorite,
           name: _('ふぁぼふぁぼする'),
-          condition: Plugin::Command[:CanFavoriteAny],
+          condition: ->opt{ opt.messages.any?{|m| favorite?(opt.world, m) && !favorited?(opt.world, m) } },
           visible: true,
-          icon: Skin['unfav.png'],
+          icon: Skin[:unfav],
           role: :timeline) do |opt|
-    world, = Plugin.filtering(:world_current, nil)
     Delayer::Deferred.when(
       opt.messages.select{|m|
-        favorite?(world, m) && !favorited?(world, m)
+        favorite?(opt.world, m) && !favorited?(opt.world, m)
       }.map{|m|
-        favorite(world, m)
+        favorite(opt.world, m)
       }
     ).terminate(_('ふぁぼふぁぼしている途中でエラーが発生しました'))
   end
 
   command(:delete_favorite,
           name: _('あんふぁぼ'),
-          condition: Plugin::Command[:IsFavoritedAll],
+          condition: ->opt{ !opt.messages.empty? && opt.messages.all?{|m| unfavorite?(opt.world, m) } },
           visible: true,
-          icon: Skin['fav.png'],
+          icon: Skin[:fav],
           role: :timeline) do |opt|
-    world, = Plugin.filtering(:world_current, nil)
     Delayer::Deferred.when(
-      opt.messages.map{|m| unfavorite(world, m) }
+      opt.messages.map{|m| unfavorite(opt.world, m) }
     ).terminate(_('あんふぁぼしている途中でエラーが発生しました'))
   end
 
   command(:delete,
           name: _('削除'),
-          condition: Plugin::Command[:IsMyMessageAll],
+          condition: ->opt{ !opt.messages.empty? && opt.messages.all?{|m| m.from_me?(opt.world) } },
           visible: true,
-          icon: Skin['close.png'],
+          icon: Skin[:close],
           role: :timeline) do |opt|
     opt.messages.deach { |m|
       +dialog(_('削除')) {
@@ -130,31 +126,46 @@ Plugin.create :command do
     }
   end
 
+  command(:aboutuser,
+          name: ->(opt) {
+            if opt
+              (_("%{title}について") % { title: opt.messages&.first&.user&.title }).gsub(/_/, '__')
+            else
+              _('投稿者について')
+            end
+          },
+          condition: ->(opt) { !opt.messages.empty? && compose?(opt.world, to: opt.messages) },
+          visible: true,
+          icon: ->(opt) { opt && opt.messages.first.user.icon },
+          role: :timeline) do |opt|
+    Plugin.call(:open, opt.messages.first.user) end
+
   command(:select_prev,
           name: _('一つ上のメッセージを選択'),
-          condition: ret_nth,
+          condition: :itself.to_proc,
           visible: false,
           role: :timeline) do |opt|
     Plugin.call(:gui_timeline_move_cursor_to, opt.widget, :prev) end
 
   command(:select_next,
           name: _('一つ下のメッセージを選択'),
-          condition: ret_nth,
+          condition: :itself.to_proc,
           visible: false,
           role: :timeline) do |opt|
     Plugin.call(:gui_timeline_move_cursor_to, opt.widget, :next) end
 
   command(:post_it,
           name: _('投稿する'),
-          condition: Plugin::Command[:Editable],
+          condition: ->opt{ opt.widget&.editable? },
           visible: true,
-          icon: Skin['post.png'],
+          icon: Skin[:post],
           role: :postbox) do |opt|
-    opt.widget.post_it! end
+    opt.widget.post_it!(world: opt.world)
+  end
 
   command(:google_search,
           name: _('ggrks'),
-          condition: Plugin::Command[:HasOneMessage, :TimelineTextSelected],
+          condition: ->opt{ opt.messages.size == 1 && opt.widget.selected_text(opt.messages.first) },
           visible: true,
           icon: "https://www.google.co.jp/images/google_favicon_128.png",
           role: :timeline) do |opt|
@@ -162,15 +173,17 @@ Plugin.create :command do
 
   command(:open_in_browser,
           name: _('ブラウザで開く'),
-          condition: Plugin::Command[:HasOneMessage, :HasParmaLinkAll],
+          condition: ->opt{ opt.messages.size == 1 && opt.messages.first.perma_link },
           visible: true,
           role: :timeline) do |opt|
     Plugin.call(:open, Diva::Model(:web)&.new(perma_link: opt.messages.first.perma_link)) end
 
   command(:open_link,
           name: _('リンクを開く'),
-          condition: Plugin::Command[:HasOneMessage] & lambda{ |opt|
-            opt.messages[0].entity.to_a.any? {|u| [:urls, :media].include?(u[:slug]) } },
+          condition: ->opt{
+            opt.messages.size == 1 &&
+              opt.messages[0].entity.to_a.any? {|u| [:urls, :media].include?(u[:slug]) }
+          },
           visible: true,
           role: :timeline) do |opt|
     opt.messages[0].entity.to_a.each {|u|
@@ -185,8 +198,10 @@ Plugin.create :command do
 
   command(:copy_link,
           name: _('リンクをコピー'),
-          condition: Plugin::Command[:HasOneMessage] & lambda{ |opt|
-            opt.messages[0].entity.to_a.any? {|u| u[:slug] == :urls } },
+          condition: ->opt{
+            opt.messages.size == 1 &&
+              opt.messages[0].entity.to_a.any? {|u| u[:slug] == :urls }
+          },
           visible: true,
           role: :timeline) do |opt|
     opt.messages[0].entity.to_a.each {|u|
@@ -194,9 +209,10 @@ Plugin.create :command do
 
   command(:new_pane,
           name: _('新規ペインに移動'),
-          condition: lambda{ |opt|
+          condition: ->opt{
             pane = opt.widget.parent
-            pane.is_a?(Plugin::GUI::Pane) and pane.children.size != 1 },
+            pane.is_a?(Plugin::GUI::Pane) && pane.children.size != 1
+          },
           visible: true,
           role: :tab) do |opt|
     tab = opt.widget.is_a?(Plugin::GUI::Tab) ? opt.widget : opt.widget.ancestor_of(Plugin::GUI::Tab)
@@ -212,17 +228,18 @@ Plugin.create :command do
 
   command(:close,
           name: _('タブを閉じる'),
-          condition: lambda{ |opt|
-            opt.widget.deletable },
+          condition: ->opt{
+            opt.widget.deletable
+          },
           visible: true,
-          icon: Skin['close.png'],
+          icon: Skin[:close],
           role: :tab) do |opt|
     opt.widget.destroy
   end
 
   command(:focus_right_tab,
           name: _('次のタブを選択'),
-          condition: lambda{ |opt| true },
+          condition: :itself.to_proc,
           visible: false,
           role: :tab) do |opt|
     focus_move_widget(opt.widget, 1)
@@ -230,7 +247,7 @@ Plugin.create :command do
 
   command(:focus_left_tab,
           name: _('前のタブを選択'),
-          condition: lambda{ |opt| true },
+          condition: :itself.to_proc,
           visible: false,
           role: :tab) do |opt|
     focus_move_widget(opt.widget, -1)
@@ -238,7 +255,7 @@ Plugin.create :command do
 
   command(:focus_right_pane,
           name: _('右のペインを選択'),
-          condition: lambda{ |opt| true },
+          condition: :itself.to_proc,
           visible: false,
           role: :pane) do |opt|
     focus_move_widget(opt.widget, -1)
@@ -246,7 +263,7 @@ Plugin.create :command do
 
   command(:focus_left_pane,
           name: _('左のペインを選択'),
-          condition: lambda{ |opt| true },
+          condition: :itself.to_proc,
           visible: false,
           role: :pane) do |opt|
     focus_move_widget(opt.widget, 1)
@@ -254,11 +271,12 @@ Plugin.create :command do
 
   command(:focus_to_postbox,
           name: _('投稿ボックスにフォーカス'),
-          condition: lambda{ |opt|
+          condition: ->opt{
             if opt.widget.respond_to? :active_chain
               not opt.widget.active_chain.last.is_a? Plugin::GUI::Postbox
             else
-              opt.widget.is_a? Plugin::GUI::Postbox end },
+              opt.widget.is_a? Plugin::GUI::Postbox end
+          },
           visible: false,
           role: :window) do |opt|
     focus_move_to_nearest_postbox(opt.widget.active_chain.last)
@@ -266,7 +284,7 @@ Plugin.create :command do
 
   command(:focus_to_tab,
           name: _('タブにフォーカス'),
-          condition: lambda{ |opt| true },
+          condition: :itself.to_proc,
           visible: false,
           role: :postbox) do |opt|
     focus_move_to_latest_widget(opt.widget)
@@ -274,7 +292,7 @@ Plugin.create :command do
 
   command(:timeline_scroll_to_top,
           name: _('タイムラインの一番上にジャーンプ！'),
-          condition: lambda{ |opt| true },
+          condition: :itself.to_proc,
           visible: false,
           role: :timeline) do |opt|
     opt.widget.scroll_to_top end
