@@ -27,7 +27,7 @@ Plugin.create(:message_detail_view) do
     else
       container = Gtk::DivaHeaderWidget.new(message, intent_token: token)
       i_cluster = tab slug, _("詳細タブ") do
-        set_icon Skin['message.png']
+        set_icon Skin[:message]
         set_deletable true
         temporary_tab
         shrink
@@ -57,9 +57,9 @@ Plugin.create(:message_detail_view) do
       bg_style.set_bg(Gtk::STATE_INSENSITIVE, *color) end end
 
   message_fragment :body, "body" do
-    set_icon Skin['message.png']
+    set_icon Skin[:message]
     container = Gtk::HBox.new
-    textview = Gtk::IntelligentTextview.new(model.to_s, 'font' => :mumble_basic_font, style: style)
+    textview = Gtk::IntelligentTextview.new(model.description, 'font' => :mumble_basic_font, style: style)
     vscrollbar = Gtk::VScrollbar.new
     textview.set_scroll_adjustment(nil, vscrollbar.adjustment)
     container.add textview
