@@ -2,7 +2,6 @@
 # coding: utf-8
 require 'nokogiri'
 require 'httpclient'
-require 'totoridipjp'
 require 'json'
 
 module Plugin::PhotoSupport
@@ -179,13 +178,6 @@ Plugin.create :photo_support do
     open('http://d250g2.com/d250g2.jpg')
   end
 
-  # totori.dip.jp
-  defimageopener('totori.dip.jp', %r#\Ahttp://totori\.dip\.jp/?\Z#) do |display_url|
-    iwashi = Totoridipjp.イワシがいっぱいだあ…ちょっとだけもらっていこうかな
-    if iwashi.url
-      open(iwashi.url) end
-  end
-
   # 600eur.gochiusa.net
   defimageopener('600eur.gochiusa.net', %r#\Ahttp://600eur\.gochiusa\.net/?\Z#) do |display_url|
     img = Plugin::PhotoSupport.d250g2(display_url)
