@@ -110,9 +110,28 @@ def notice(msg)
   log "notice", msg if Mopt.error_level >= 3
 end
 
-# 警告メッセージを表示する。
-def warn(msg)
-  log "warning", msg if Mopt.error_level >= 2
+if Gem::Version.new(RUBY_VERSION) >= Gem::Version.new('2.5.0')
+  alias __mikutter_original_warn warn
+  # 警告メッセージを表示する。
+  def warn(*msg, uplevel: nil)
+    case
+    when uplevel
+      __mikutter_original_warn(*msg, uplevel: uplevel)
+    when Mopt.error_level >= 2
+      msg.each do |m|
+        log "warning", m
+      end
+    end
+  end
+else
+  # 警告メッセージを表示する。
+  def warn(*msg)
+    if Mopt.error_level >= 2
+      msg.each do |m|
+        log "warning", m
+      end
+    end
+  end
 end
 
 # エラーメッセージを表示する。
@@ -192,11 +211,13 @@ def tcor(*types)
 # type_checkと同じだが、チェックをパスしなかった場合にabortする
 # type_checkの戻り値を返す
 def type_strict(args, &proc)
-  result = type_check(args, &proc)
-  if not result
-    into_debug_mode(binding)
-    raise ArgumentError.new end
-  result end
+  args.each.with_index do |(value, constraint), index|
+    unless type_check(value => constraint, &proc)
+      raise TypeStrictError.new("The ##{index} value does not matched constraint `#{constraint}'", value: value)
+    end
+  end
+  true
+end
 
 # blockの評価結果がチェックをパスしなかった場合にabortする
 def result_strict(must, &block)
@@ -462,3 +483,15 @@ class Regexp
     new(o['data'])
   end
 end
+
+# type_strictが発生させる例外。
+# 値が制約に合致しない場合に投げられる。
+# valueメソッドを呼ぶと、原因となった値を得ることができる。
+class TypeStrictError < TypeError
+  attr_reader :value
+
+  def initialize(*args, value:)
+    super(*args)
+    @value = value
+  end
+end
